@@ -9,8 +9,6 @@
 #
 # This file from: https://github.com/WojciechMula/canvas2svg
 
-from __future__ import division
-
 __author__  = "Wojciech Muła <wojciech_mula@poczta.onet.pl>"
 
 __all__ = ["convert", "SVGdocument", "saveall", "PYTHON", "MODULE", "NONE",
@@ -66,10 +64,11 @@ def configure(*flags):
                 "Please use one of constants: SEGMENT_TO_LINE, SEGMENT_TO_PATH"
             )
 
+
 def convert(document, canvas, items=None, tounicode=None):
     """
     Convert 'items' stored in 'canvas' to SVG 'document'.
-    If 'items' is None, then all items are convered.
+    If 'items' is None, then all items are converted.
 
     tounicode is a function that get text and returns
     it's unicode representation. It should be used when
@@ -707,7 +706,7 @@ text_anchor = {
     E    : "end",
     NE    : "end",
 
-    SW    : "", # SVG defaul (value "start")
+    SW    : "", # SVG default (value "start")
     W    : "",
     NW    : "",
 
